@@ -1,12 +1,20 @@
 # -*- coding: utf-8 -*-
 
-"""Colors module.
+"""Text colorization.
 
 This module implements features related to text colorization.
+
 """
 
+from codecs import decode
+from logging import getLogger
+
 from treecker import config
 
+
+logger = getLogger(__name__)
+
+
 def get_code(name):
     """Return the color code.
 
@@ -21,8 +29,10 @@ def get_code(name):
         Color code.
 
     """
+    logger.debug("retrieving '%s' color code", name)
     color = config.get(__name__, name)
-    return eval(f"'{color}'")
+    return decode(color, 'unicode_escape')
+
 
 def colorize(string, color):
     """Return the colorized string.
@@ -40,6 +50,7 @@ def colorize(string, color):
         Colorized text.
 
     """
+    logger.debug("colorizing text with color '%s'", color)
     start = get_code(color)
     end = get_code('end')
     return start + string + end
