@@ -3,14 +3,20 @@
 """Comparison module.
 
 This module implements the comparison between two trees.
+
 """
 
+from logging import getLogger
 from pathlib import Path
 
 from treecker import config
 from treecker.core.colors import colorize
 
-def differences(old, new, hash, path=[]):
+
+logger = getLogger(__name__)
+
+
+def get_differences(old, new, hashing, path=None):
     """Return a list of the differences between two tree objects.
 
     Parameters
@@ -19,7 +25,7 @@ def differences(old, new, hash, path=[]):
         Old directory node.
     new : dict
         New directory node.
-    hash : bool
+    hashing : bool
         Compare file hash values.
     path : list
         Initial path.
@@ -30,23 +36,32 @@ def differences(old, new, hash, path=[]):
         Differences betwen the two nodes.
 
     """
+    logger.debug("getting differences at %s", path)
+    if path is None:
+        path = []
     listing = []
     if isinstance(old, dict) and isinstance(new, dict):
-        for n in old:
-            if n in new:
-                listing += differences(old[n], new[n], hash, path+[n])
+        for node in old:
+            if node in new:
+                listing += get_differences(
+                    old[node],
+                    new[node],
+                    hashing,
+                    path+[node],
+                )
             else:
-                listing.append({'type': 'removed', 'path': path+[n]})
-        for n in new:
-            if not n in old:
-                listing.append({'type': 'added', 'path': path+[n]})
+                listing.append({'type': 'removed', 'path': path+[node]})
+        for node in new:
+            if node not in old:
+                listing.append({'type': 'added', 'path': path+[node]})
     elif isinstance(old, dict) or isinstance(new, dict):
         listing.append({'type': 'removed', 'path': path})
         listing.append({'type': 'added', 'path': path})
-    elif (old[0] != new[0]) or hash and (old[1] != new[1]):
+    elif (old[0] != new[0]) or hashing and (old[1] != new[1]):
         listing.append({'type': 'edited', 'path': path})
     return listing
 
+
 def differences_log(differences):
     """Return a printable log of the differences.
 
@@ -61,19 +76,19 @@ def differences_log(differences):
         Differences log.
 
     """
+    logger.debug("creating difference log")
     color, symbol = {}, {}
     for name, value in config[__name__].items():
-        if name.startswith('color-'):
-            color[name[6:]] = eval(f"'{value}'")
-        elif name.startswith('symbol-'):
+        if name.startswith('color_'):
+            color[name[6:]] = value
+        elif name.startswith('symbol_'):
             symbol[name[7:]] = value
     lines = []
     for diff in differences:
-        type = diff['type']
         path = Path(*diff['path'])
-        line = colorize(f"{symbol[type]} {path}", color[type])
+        line = colorize(f"{symbol[diff['type']]} {path}", color[diff['type']])
         lines.append(line)
     if len(differences) == 0:
-        lines.append(f"no change found")
+        lines.append("no change found")
     log = "\n".join(lines)
     return log
