@@ -1,18 +1,24 @@
 # -*- coding: utf-8 -*-
 
-"""Commit feature module.
+"""Commit feature.
 
 This module implements the feature that allows to save in a new
 snapshot the changes that have occurred in the directory.
+
 """
 
 from datetime import datetime, timezone
+from logging import getLogger
 from os.path import join
 
 from treecker import config
-from treecker.core.comparison import differences, differences_log
+from treecker.core.comparison import get_differences, differences_log
 from treecker.core.snapshot import initialized, load, save, take
 
+
+logger = getLogger(__name__)
+
+
 def setup(parser):
     """Configure the parser for the module.
 
@@ -22,14 +28,17 @@ def setup(parser):
         Parser dedicated to the module.
 
     """
+    logger.debug("defining command-line arguments")
     parser.set_defaults(
         func=main,
     )
-    parser.add_argument('--dir',
+    parser.add_argument(
+        '--dir',
         help="path to the tracked directory",
         type=str,
     )
 
+
 def main(**kwargs):
     """Save the changes in a new snapshot.
 
@@ -39,30 +48,35 @@ def main(**kwargs):
         Path to the tracked directory.
 
     """
-    directory = str(kwargs.get('dir', '.'))
-    # load directory configuration
-    config.read(join(directory, config.get('DEFAULT', 'conf-file')))
-    # check that the directory is tracked before loading latest snapshot
-    if not initialized(directory):
-        raise Exception(f"treecker not initialized in {directory}")
-    snap1 = load(directory)
-    # inform user
+    logger.debug("retrieving parameters")
+    kwargs.setdefault('dir', config.get(__name__, 'dir'))
+
+    logger.debug("loading latest snapshot")
+    config.read(join(kwargs['dir'], config.get('DEFAULT', 'conf_file')))
+    if not initialized(kwargs['dir']):
+        raise FileNotFoundError(f"{kwargs['dir']} treecker not initialized")
+    snap1 = load(kwargs['dir'])
+
+    logger.debug("informing user")
     date = datetime.fromisoformat(snap1['date'])
     zone = datetime.now(timezone.utc).astimezone().tzinfo
     date = date.astimezone(zone).isoformat(timespec="seconds")
     print(f"comparing with snapshot from {date} ({zone})")
-    # hash or no hash
+
+    logger.debug("taking snapshot")
     hash1 = snap1['hash']
     hash2 = hash1
     if not hash2:
         print("comparison of files based on their size only")
-    # display differences
-    snap2 = take(directory, hash2)
-    listing = differences(snap1['tree'], snap2['tree'], hash2)
+
+    logger.debug("displaying differences")
+    snap2 = take(kwargs['dir'], hash2)
+    listing = get_differences(snap1['tree'], snap2['tree'], hash2)
     log = differences_log(listing)
     print(log)
-    # write new snapshot
+
+    logger.debug("saving new snapshot")
     if len(listing) > 0:
         if input("save modifications? (y|n) ") == "y":
-            save(directory, snap2)
-            print(f"changes commited in {directory}")
+            save(kwargs['dir'], snap2)
+            print(f"changes commited in {kwargs['dir']}")
